Enum IStablecoinDEXCalls
pub enum IStablecoinDEXCalls {
Show 25 variants
createPair(createPairCall),
place(placeCall),
placeFlip(placeFlipCall),
cancel(cancelCall),
cancelStaleOrder(cancelStaleOrderCall),
swapExactAmountIn(swapExactAmountInCall),
swapExactAmountOut(swapExactAmountOutCall),
quoteSwapExactAmountIn(quoteSwapExactAmountInCall),
quoteSwapExactAmountOut(quoteSwapExactAmountOutCall),
balanceOf(balanceOfCall),
withdraw(withdrawCall),
getOrder(getOrderCall),
getTickLevel(getTickLevelCall),
pairKey(pairKeyCall),
nextOrderId(nextOrderIdCall),
books(booksCall),
MIN_TICK(MIN_TICKCall),
MAX_TICK(MAX_TICKCall),
TICK_SPACING(TICK_SPACINGCall),
PRICE_SCALE(PRICE_SCALECall),
MIN_ORDER_AMOUNT(MIN_ORDER_AMOUNTCall),
MIN_PRICE(MIN_PRICECall),
MAX_PRICE(MAX_PRICECall),
tickToPrice(tickToPriceCall),
priceToTick(priceToTickCall),
}Expand description
Container for all the IStablecoinDEX function calls.
Variants
createPair(createPairCall)
place(placeCall)
placeFlip(placeFlipCall)
cancel(cancelCall)
cancelStaleOrder(cancelStaleOrderCall)
swapExactAmountIn(swapExactAmountInCall)
swapExactAmountOut(swapExactAmountOutCall)
quoteSwapExactAmountIn(quoteSwapExactAmountInCall)
quoteSwapExactAmountOut(quoteSwapExactAmountOutCall)
balanceOf(balanceOfCall)
withdraw(withdrawCall)
getOrder(getOrderCall)
getTickLevel(getTickLevelCall)
pairKey(pairKeyCall)
nextOrderId(nextOrderIdCall)
books(booksCall)
MIN_TICK(MIN_TICKCall)
MAX_TICK(MAX_TICKCall)
TICK_SPACING(TICK_SPACINGCall)
PRICE_SCALE(PRICE_SCALECall)
MIN_ORDER_AMOUNT(MIN_ORDER_AMOUNTCall)
MIN_PRICE(MIN_PRICECall)
MAX_PRICE(MAX_PRICECall)
tickToPrice(tickToPriceCall)
priceToTick(priceToTickCall)
Implementations
impl IStablecoinDEXCalls
impl IStablecoinDEXCalls
pub const SELECTORS: &'static [[u8; 4]]
pub const SELECTORS: &'static [[u8; 4]]
All the selectors of this enum.
Note that the selectors might not be in the same order as the variants. No guarantees are made about the order of the selectors.
Prefer using SolInterface methods instead.
pub const VARIANT_NAMES: &'static [&'static str]
pub const VARIANT_NAMES: &'static [&'static str]
The names of the variants in the same order as SELECTORS.
pub const SIGNATURES: &'static [&'static str]
pub const SIGNATURES: &'static [&'static str]
The signatures in the same order as SELECTORS.
pub fn signature_by_selector(selector: [u8; 4]) -> Option<&'static str>
pub fn signature_by_selector(selector: [u8; 4]) -> Option<&'static str>
Returns the signature for the given selector, if known.
pub fn name_by_selector(selector: [u8; 4]) -> Option<&'static str>
pub fn name_by_selector(selector: [u8; 4]) -> Option<&'static str>
Returns the enum variant name for the given selector, if known.