Enum IStablecoinDEXEvents
pub enum IStablecoinDEXEvents {
PairCreated(PairCreated),
OrderPlaced(OrderPlaced),
OrderFilled(OrderFilled),
OrderCancelled(OrderCancelled),
}Expand description
Container for all the IStablecoinDEX events.
Variants
PairCreated(PairCreated)
OrderPlaced(OrderPlaced)
OrderFilled(OrderFilled)
OrderCancelled(OrderCancelled)
Implementations
impl IStablecoinDEXEvents
impl IStablecoinDEXEvents
pub const SELECTORS: &'static [[u8; 32]]
pub const SELECTORS: &'static [[u8; 32]]
All the selectors of this enum.
Note that the selectors might not be in the same order as the variants. No guarantees are made about the order of the selectors.
Prefer using SolInterface methods instead.
pub const VARIANT_NAMES: &'static [&'static str]
pub const VARIANT_NAMES: &'static [&'static str]
The names of the variants in the same order as SELECTORS.
pub const SIGNATURES: &'static [&'static str]
pub const SIGNATURES: &'static [&'static str]
The signatures in the same order as SELECTORS.
pub fn signature_by_selector(selector: [u8; 32]) -> Option<&'static str>
pub fn signature_by_selector(selector: [u8; 32]) -> Option<&'static str>
Returns the signature for the given selector, if known.
pub fn name_by_selector(selector: [u8; 32]) -> Option<&'static str>
pub fn name_by_selector(selector: [u8; 32]) -> Option<&'static str>
Returns the enum variant name for the given selector, if known.